cheesecake.cheesecake_index.CheesecakeError

Package cheesecake :: Module cheesecake_index :: Class CheesecakeError |
[hide private]
[frames] | no frames]

## Class CheesecakeError
source code

    exceptions.Exception --+
                           |
                          CheesecakeError

Custom exception class for Cheesecake-specific errors.

Instance Methods | [hide private]
Inherited from `exceptions.Exception`: `__getitem__`, `__init__`, `__str__`